==> openshift-model-monitoring-5.7.3-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusRuleBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PrometheusRuleBuilder extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleBuilder>{
  public PrometheusRuleBuilder() {
    this(false);
  }
  public PrometheusRuleBuilder(java.lang.Boolean validationEnabled) {
    this(new PrometheusRule(), validationEnabled);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PrometheusRule(), validationEnabled);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule instance) {
    this(fluent, instance, false);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule instance) {
    this(instance,false);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule build() {
    PrometheusRule buildable = new PrometheusRule(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PrometheusRuleBuilder that = (PrometheusRuleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusRuleBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PrometheusRuleBuilder extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleBuilder>{
  public PrometheusRuleBuilder() {
    this(false);
  }
  public PrometheusRuleBuilder(java.lang.Boolean validationEnabled) {
    this(new PrometheusRule(), validationEnabled);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PrometheusRule(), validationEnabled);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule instance) {
    this(fluent, instance, false);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule instance) {
    this(instance,false);
  }
  public PrometheusRuleBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusRule build() {
    PrometheusRule buildable = new PrometheusRule(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PrometheusRuleBuilder that = (PrometheusRuleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
